@@ -4,6 +4,12 @@
 # Copyright(c) 2013 Krister Hedfors
 #
 
+__all__ = (
+    'Test_Netmask',
+    'Test_IPRangeIterator',
+)
+
+
 import doctest
 import unittest
 
