@@ -28,8 +28,8 @@ class ResolvTool(Tool):
     ]
 
     @classmethod
-    def print_source(self):
-        print open(__file__).read()
+    def print_source(cls):
+        cls._print_source(__file__)
 
     def __parse__(self, line, iterator):
         self._item = item = line.strip()
